@@ -27,9 +27,9 @@ use std::convert::TryFrom;
 ///
 #[derive(Eq, PartialEq, Hash, Copy, Clone, Debug)]
 pub enum Urgency {
-    /// The behaviour for `Low` urgency depends on the notification server.
+    /// The behavior for `Low` urgency depends on the notification server.
     Low = 0,
-    /// The behaviour for `Normal` urgency depends on the notification server.
+    /// The behavior for `Normal` urgency depends on the notification server.
     Normal = 1,
     /// A critical notification will not time out.
     Critical = 2,
@@ -63,6 +63,8 @@ impl From<Option<u64>> for Urgency {
     }
 }
 
+// TODO: remove this in v5.0
+#[cfg(not(feature = "server"))]
 impl From<u64> for Urgency {
     fn from(int: u64) -> Urgency {
         match int {
@@ -72,3 +74,15 @@ impl From<u64> for Urgency {
         }
     }
 }
+
+// TODO: make this the default in v5.0
+#[cfg(feature = "server")]
+impl From<u8> for Urgency {
+    fn from(int: u8) -> Urgency {
+        match int {
+            0 => Urgency::Low,
+            1 => Urgency::Normal,
+            2..=std::u8::MAX => Urgency::Critical,
+        }
+    }
+}
